# Sail Mate



## Overview
Sail Mate is a simple chess engine built completly from scratch using python and OOP. It supports standard piece movement, simple FEN strings, simple evaluation, and a minimax algorith with alphabeta pruning. Moreover, you can also play with the engine from the command line. Having said that, it does not support under promotion, draws by repetition, or the 50 move rules. Due to being poorly optimizes, and in python, it is also quite slow. I did it mainly as a learning exercise, to have fun, and to submit it to ShipWrecked

<div align="center">
  <a href="https://shipwrecked.hackclub.com/?t=ghrm" target="_blank">
    <img src="https://hc-cdn.hel1.your-objectstorage.com/s/v3/739361f1d440b17fc9e2f74e49fc185d86cbec14_badge.png" 
         alt="This project is part of Shipwrecked, the world's first hackathon on an island!" 
         style="width: 35%;">
  </a>
</div>
